LiteRtLayoutView class

View over a LiteRtLayout* filled in by the C API.

Constructors

LiteRtLayoutView.calloc()
Allocate a zeroed layout. Free with free.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
pointer Pointer<Void>
Pass to LiteRt accessor functions (e.g. getInputTensorLayout).
no setter
rank int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dimension(int i) int
free() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited